Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2898)

Unified Diff: build/android/pylib/linker/test_runner.py

Issue 26251003: android: Add 4 new linker tests. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Address Marcus' nits. Created 7 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « build/android/pylib/linker/test_case.py ('k') | build/android/test_runner.py » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: build/android/pylib/linker/test_runner.py
diff --git a/build/android/pylib/linker/test_runner.py b/build/android/pylib/linker/test_runner.py
index a0b486017c0ef51d4ac911ff143170d38ec1e96e..3b4ee5cb3d0023353c65c40e5b7ce46b3cc02b1c 100644
--- a/build/android/pylib/linker/test_runner.py
+++ b/build/android/pylib/linker/test_runner.py
@@ -80,14 +80,14 @@ class LinkerTestRunner(base_test_runner.BaseTestRunner):
"""Sets up and runs a test case.
Args:
test: An object which is ostensibly a subclass of LinkerTestCase.
Returns:
A TestRunResults object which contains the result produced by the test
and, in the case of a failure, the test that should be retried.
"""
- assert isinstance(test, test_case.LinkerTestCase)
+ assert isinstance(test, test_case.LinkerTestCaseBase)
try:
results = test.Run(self.device)
« no previous file with comments | « build/android/pylib/linker/test_case.py ('k') | build/android/test_runner.py » ('j') | no next file with comments »
@@ -80,14 +80,14 @@ class LinkerTestRunner(base_test_runner.BaseTestRunner):
"""Sets up and runs a test case.
Args:
- test: An object which is ostensibly a subclass of LinkerTestCase.
+ test: An object which is ostensibly a subclass of LinkerTestCaseBase.
Returns:
A TestRunResults object which contains the result produced by the test

Powered by Google App Engine
This is Rietveld 408576698